@@ -7,8 +7,8 @@
 */
 
 #include <QCoreApplication>
+#include <QList>
 #include <QMutex>
-#include <QVector>
 
 #include "queue.h"
 #include "weaver.h"
@@ -106,7 +106,6 @@ const State *Queue::state() const
 
 namespace
 {
-
 class StaticThreadWeaverInstanceGuard : public QObject
 {
     Q_OBJECT
@@ -116,18 +115,19 @@ public:
         , instance_(instance)
     {
         Q_ASSERT_X(app != nullptr, Q_FUNC_INFO, "Calling ThreadWeaver::Weaver::instance() requires a QCoreApplication!");
-        QObject *impl = instance.loadRelaxed()->findChild<QueueSignals*>();
+        QObject *impl = instance.loadRelaxed()->findChild<QueueSignals *>();
         Q_ASSERT(impl);
         impl->setObjectName(QStringLiteral("GlobalQueue"));
         qAddPostRoutine(shutDownGlobalQueue);
     }
 
-    ~StaticThreadWeaverInstanceGuard()
+    ~StaticThreadWeaverInstanceGuard() override
     {
         instance_.fetchAndStoreOrdered(nullptr);
         delete globalQueueFactory;
         globalQueueFactory = nullptr;
     }
+
 private:
     static void shutDownGlobalQueue()
     {
@@ -151,29 +151,27 @@ private:
  */
 Queue *Queue::instance()
 {
-    static QAtomicPointer<Queue> s_instance(globalQueueFactory
-            ? globalQueueFactory->create(qApp)
-            : new Queue(qApp));
-    //Order is of importance here:
-    //When s_instanceGuard is destructed (first, before s_instance), it sets the value of s_instance to zero. Next, qApp will delete
-    //the object s_instance pointed to.
+    static QAtomicPointer<Queue> s_instance(globalQueueFactory ? globalQueueFactory->create(qApp) : new Queue(qApp));
+    // Order is of importance here:
+    // When s_instanceGuard is destructed (first, before s_instance), it sets the value of s_instance to zero. Next, qApp will delete
+    // the object s_instance pointed to.
     static StaticThreadWeaverInstanceGuard *s_instanceGuard = new StaticThreadWeaverInstanceGuard(s_instance, qApp);
     Q_UNUSED(s_instanceGuard);
-    Q_ASSERT_X(s_instance.loadRelaxed() == nullptr ||
-               s_instance.loadRelaxed()->thread() == QCoreApplication::instance()->thread(),
+    Q_ASSERT_X(s_instance.loadRelaxed() == nullptr //
+                   || s_instance.loadRelaxed()->thread() == QCoreApplication::instance()->thread(),
                Q_FUNC_INFO,
                "The global ThreadWeaver queue needs to be instantiated (accessed first) from the main thread!");
     return s_instance.loadAcquire();
 }
 
-void Queue::enqueue(const QVector<JobPointer> &jobs)
+void Queue::enqueue(const QList<JobPointer> &jobs)
 {
     d->implementation->enqueue(jobs);
 }
 
 void Queue::enqueue(const JobPointer &job)
 {
-    enqueue(QVector<JobPointer>() << job);
+    enqueue(QList<JobPointer>() << job);
 }
 
 bool Queue::dequeue(const JobPointer &job)
@@ -241,4 +239,5 @@ void Queue::reschedule()
     d->implementation->reschedule();
 }
 
+#include "moc_queue.cpp"
 #include "queue.moc"
